@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -30,7 +31,6 @@ class InboxRecipient:
     def get_attributes(self):
         return {k: getattr(self, k, None) for k in InboxRecipient.default_attributes if getattr(self, k, None) is not None}
 
-
     def save(self):
         if hasattr(self, "id") and self.id:
             raise NotImplementedError("The InboxRecipient object doesn't support updates.")
@@ -40,15 +40,15 @@ class InboxRecipient:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `has_registrations`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `has_registrations`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `has_registrations`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `has_registrations`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `has_registrations`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `has_registrations`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `has_registrations`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `has_registrations`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `has_registrations`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `has_registrations`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `has_registrations`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `has_registrations`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `has_registrations`.
 #   inbox_id (required) - int64 - List recipients for the inbox with this ID.
 def list(params = None, options = None):
     if not isinstance(params, dict):
